@@ -1,4 +1,5 @@
 from .civic_clerk.site import CivicClerkSite
 from .civic_plus.site import Site as CivicPlusSite
 from .granicus.site import GranicusSite
-from .legistar.site import LegistarSite
+from .legistar.site import Site as LegistarSite
+from .primegov.site import PrimeGovSite
